@@ -107,7 +107,7 @@ class KeywordsList:
     def getPostagScore(self,w):
         shell = 1
         if shell:
-            proc = subprocess.Popen(["echo '"+w+"' | tree-tagger -lemma -quiet "+self.treetagger+"/lib/french-utf8.par |cut -d ' ' -f 1", ""], stdout=subprocess.PIPE, shell=True)
+            proc = subprocess.Popen(["echo '"+w+"' | tree-tagger -lemma -quiet "+self.treetagger+"lib/french-utf8.par |cut -d ' ' -f 1", ""], stdout=subprocess.PIPE, shell=True)
             (out, err) = proc.communicate()
             #print "Category:", out
             # Depending on category, score
