@@ -12,6 +12,8 @@ class Parameters:
         rel_path = "parameters.yml"
         abs_file_path = os.path.join(script_dir, rel_path)
 
+        self.paramfile = abs_file_path
+
         stream = open(abs_file_path, "r")
         docs = yaml.load_all(stream)
         for doc in docs:
@@ -58,3 +60,8 @@ class Parameters:
                 for k,v in doc.items():
                     print k, "->", v
                 print "\n",
+
+    def change(self):
+        print "Editing params file"
+        print self.paramfile
+        #subprocess.call(["vim "+self.paramfile])
